AIG balancing
-------------

**Header:** ``mockturtle/algorithms/aig_balancing.hpp``

Parameters
~~~~~~~~~~

.. doxygenstruct:: mockturtle::aig_balancing_params
   :members:

Algorithm
~~~~~~~~~

.. doxygenfunction:: mockturtle::aig_balance
